# Copyright(C) 2007 Brazil
#     All rights reserved.
#     This is free software with ABSOLUTELY NO WARRANTY.
#
# You can redistribute it and/or modify it under the terms of
# the GNU General Public License version 2.
require 'test/unit'
require 'senna'
require 'test_tools'

$KCODE = 'e'

class FixedBugRev00644Test < Test::Unit::TestCase
  include TestTools

  def test_many_spaces_snippet
    res = Senna::Snip::open(euc2utf8('̴'), 300, 1, '(', ')', nil, Senna::ENC_UTF8).
    exec(euc2utf8('ڡäѤ̴äѤ'))
    assert_equal([euc2utf8('(̴)')], res)
  end
end
